@@ -60,7 +60,13 @@ def table_info(datatable_code):
     
     if 'datatable' in r:
         r=r['datatable']
-        r['status']['refreshed_at']=datetime.datetime.strptime(r['status']['refreshed_at'],"%Y-%m-%dT%H:%M:%SZ")
+        
+        if r['status']['refreshed_at']:
+            try:
+                r['status']['refreshed_at']=datetime.datetime.strptime(r['status']['refreshed_at'],"%Y-%m-%dT%H:%M:%SZ")
+            except:
+                pass
+            
         cols = {}
         for col in r['columns']:
             cols[col['name']]=col
